WikiCreole help.

Wiki | Rendered
--- | ---
`//italics//` | italics
`**bold**` | bold
`__underline__` | underline
`^^super^^script` | superscript
`,,sub,,script` | subscript
`##monospace##` | `monospace`
    * Bullet list
    * Second item
    ** Sub item
| Bullet list Second item Sub item
    # Numbered list
    # Second item
    ## Sub item
| Numbered list Second item Sub item
    # Mixed list
    ** Sub bullet item
    # Numbered item
| Mixed list Sub bullet item Numbered item
    ; Definition List
    : Definition
| Definition List Definition
    == Large heading
    === Medium Heading
    ==== Small heading
| ## Large heading ### Medium Heading #### Small heading
    No
    linebreak!

    Use empty row
| No linebreak! Use empty row
`Force\\linebreak` | Force linebreak
    Horizontal line:
    ----
| Horizontal line:
    |=|=table|=header|
    |a|table|row|
    |b|table|row|
| table | header
--- | --- | ---
a | table | row
b | table | row
    > Indented regions\\
    > can include
    >> block elements
| Indented regions can include block elements
use a tilde to ~**escape | use a tilde to **escape
`[[http://google.com|Google]]` | external link to Google.
`{{http://some.where.com/external/Image.jpg|Title}}` | Include external image
`<<img NNN>> <<img NNN href=http://www.google.com/>> <<img NNN w=400>>` | Вставка приаттаченого к статье изображения. необходимо указать его номер, можно указать ширину. изображение может быть ссылкой на ресурс.
`<<yt mHyTOcfF99o>> <<yt mHyTOcfF99o w=400>>` | Вставка ролика с YouTube. необходимо указать код ролика, можно указать ширину "телевизора".